@@ -65,7 +65,7 @@ class Server:
         return self.handle_response(
             self.send_message(rpc.request(method_name, *args, **kwargs)), False)
 
-    def send_message(self, request_dict):
+    def send_message(self, request):
         """Send the RPC request to the server.
 
         Calls a procedure on another server.
@@ -73,18 +73,22 @@ class Server:
         """
 
         # Log the request
-        request_log.info(json.dumps(request_dict))
+        request_log.info(json.dumps(request))
 
         try:
             # Send the message
             response = requests.post(
                 self.endpoint,
                 self.headers,
-                json=request_dict,
+                json=request,
                 auth=self.auth
             )
+        # Catch the requests module's InvalidSchema exception if the json is
+        # invalid.
         except requests.exceptions.InvalidSchema:
             raise exceptions.InvalidRequest()
+        # Catch all other requests exceptions, such as network issues.
+        # See http://stackoverflow.com/questions/16511337/
         except requests.exceptions.RequestException: # The base exception
             raise exceptions.ConnectionError()
 
